OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visionneuse",
    "Simple file viewer with slideshow for media" : "Visionneuse simple de fichiers avec diaporama pour les médias",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Affichez vos dernières photos et vidéos de vacances comme dans les films, visionnez votre dernier roman directement depuis Nextcloud, choisissez le meilleur GIF de votre collection grâce à la prévisualisation directe de vos fichiers favoris et bien plus encore !",
    "Error loading {name}" : "Erreur lors du chargement de {name}",
    "Your browser does not support the video tag." : "Votre navigateur ne supporte ce type de vidéo.",
    "Open sidebar" : "Ouvrir la barre latérale",
    "View" : "Afficher",
    "Share" : "Partager"
},
"nplurals=2; plural=(n > 1);");
